/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * A filter that merges the multiple other filters using the given operation.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class CompositeFilter extends GenericJson {

  /**
   * The list of filters to combine. Must contain at least one filter.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Filter> filters;

  static {
    // hack to force ProGuard to consider Filter used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Filter.class);
  }

  /**
   * The operator for combining multiple filters. Only "and" is currently supported.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String operator;

  /**
   * The list of filters to combine. Must contain at least one filter.
   * The value returned may be {@code null}.
   */
  public java.util.List<Filter> getFilters() {
    return filters;
  }

  /**
   * The list of filters to combine. Must contain at least one filter.
   * The value set may be {@code null}.
   */
  public CompositeFilter setFilters(java.util.List<Filter> filters) {
    this.filters = filters;
    return this;
  }

  /**
   * The operator for combining multiple filters. Only "and" is currently supported.
   * The value returned may be {@code null}.
   */
  public String getOperator() {
    return operator;
  }

  /**
   * The operator for combining multiple filters. Only "and" is currently supported.
   * The value set may be {@code null}.
   */
  public CompositeFilter setOperator(String operator) {
    this.operator = operator;
    return this;
  }

}
