/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * An identifier for a particular subset of entities.
 *
 * Entities are partitioned into various subsets, each used by different datasets and different
 * namespaces within a dataset and so forth.
 *
 * All input partition IDs are normalized before use. A partition ID is normalized as follows: If
 * the partition ID is unset, replace it with an empty partition ID. If the partition ID has no
 * dataset ID, assign it the context dataset ID.
 *
 * Partition dimension: A dimension may be unset. A dimension's value must never contain "!". A
 * dimension's value must never be "". If the value of any dimension matches regex "__.*__", the
 * partition is reserved/read-only. A reserved/read-only partition ID is forbidden in certain
 * documented contexts.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PartitionId extends GenericJson {

  /**
   * The dataset ID.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String datasetId;

  /**
   * The namespace.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String namespace;

  /**
   * The dataset ID.
   * The value returned may be {@code null}.
   */
  public String getDatasetId() {
    return datasetId;
  }

  /**
   * The dataset ID.
   * The value set may be {@code null}.
   */
  public PartitionId setDatasetId(String datasetId) {
    this.datasetId = datasetId;
    return this;
  }

  /**
   * The namespace.
   * The value returned may be {@code null}.
   */
  public String getNamespace() {
    return namespace;
  }

  /**
   * The namespace.
   * The value set may be {@code null}.
   */
  public PartitionId setNamespace(String namespace) {
    this.namespace = namespace;
    return this;
  }

}
