/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * An entity property.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Property extends GenericJson {

  /**
   * If this property contains a list of values. Input values may explicitly set multi to false, but
   * otherwise false is always represented by omitting multi.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean multi;

  /**
   * The value(s) of the property. When multi is false there is always exactly one value. When multi
   * is true there is always one or more values. Each value can have only one value property
   * populated. For example, you cannot have a values list of { values: [ { integerValue: 22,
   * stringValue: "a" } ] }, but you can have { multi: true, values: [ { integerValue: 22 }, {
   * stringValue: "a" } ] }.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Value> values;

  static {
    // hack to force ProGuard to consider Value used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Value.class);
  }

  /**
   * If this property contains a list of values. Input values may explicitly set multi to false, but
   * otherwise false is always represented by omitting multi.
   * The value returned may be {@code null}.
   */
  public Boolean getMulti() {
    return multi;
  }

  /**
   * If this property contains a list of values. Input values may explicitly set multi to false, but
   * otherwise false is always represented by omitting multi.
   * The value set may be {@code null}.
   */
  public Property setMulti(Boolean multi) {
    this.multi = multi;
    return this;
  }

  /**
   * The value(s) of the property. When multi is false there is always exactly one value. When multi
   * is true there is always one or more values. Each value can have only one value property
   * populated. For example, you cannot have a values list of { values: [ { integerValue: 22,
   * stringValue: "a" } ] }, but you can have { multi: true, values: [ { integerValue: 22 }, {
   * stringValue: "a" } ] }.
   * The value returned may be {@code null}.
   */
  public java.util.List<Value> getValues() {
    return values;
  }

  /**
   * The value(s) of the property. When multi is false there is always exactly one value. When multi
   * is true there is always one or more values. Each value can have only one value property
   * populated. For example, you cannot have a values list of { values: [ { integerValue: 22,
   * stringValue: "a" } ] }, but you can have { multi: true, values: [ { integerValue: 22 }, {
   * stringValue: "a" } ] }.
   * The value set may be {@code null}.
   */
  public Property setValues(java.util.List<Value> values) {
    this.values = values;
    return this;
  }

}
