/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * A filter on a specific property.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PropertyFilter extends GenericJson {

  /**
   * The operator to filter by. One of lessThan, lessThanOrEqual, greaterThan, greaterThanOrEqual,
   * equal, or hasAncestor.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String operator;

  /**
   * The property to filter by.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PropertyReference property;

  /**
   * The value to compare the property to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Value value;

  /**
   * The operator to filter by. One of lessThan, lessThanOrEqual, greaterThan, greaterThanOrEqual,
   * equal, or hasAncestor.
   * The value returned may be {@code null}.
   */
  public String getOperator() {
    return operator;
  }

  /**
   * The operator to filter by. One of lessThan, lessThanOrEqual, greaterThan, greaterThanOrEqual,
   * equal, or hasAncestor.
   * The value set may be {@code null}.
   */
  public PropertyFilter setOperator(String operator) {
    this.operator = operator;
    return this;
  }

  /**
   * The property to filter by.
   * The value returned may be {@code null}.
   */
  public PropertyReference getProperty() {
    return property;
  }

  /**
   * The property to filter by.
   * The value set may be {@code null}.
   */
  public PropertyFilter setProperty(PropertyReference property) {
    this.property = property;
    return this;
  }

  /**
   * The value to compare the property to.
   * The value returned may be {@code null}.
   */
  public Value getValue() {
    return value;
  }

  /**
   * The value to compare the property to.
   * The value set may be {@code null}.
   */
  public PropertyFilter setValue(Value value) {
    this.value = value;
    return this;
  }

}
