/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * A batch of results produced by a query.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class QueryResultBatch extends GenericJson {

  /**
   * A cursor that points to the position after the last result in the batch. May be absent.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String endCursor;

  /**
   * The result type for every entity in entityResults. full for full entities, projection for
   * entities with only projected properties, keyOnly for entities with only a key.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String entityResultType;

  /**
   * The results for this batch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<EntityResult> entityResults;

  static {
    // hack to force ProGuard to consider EntityResult used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(EntityResult.class);
  }

  /**
   * The state of the query after the current batch. One of notFinished, moreResultsAfterLimit,
   * noMoreResults.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String moreResults;

  /**
   * The number of results skipped because of Query.offset.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer skippedResults;

  /**
   * A cursor that points to the position after the last result in the batch. May be absent.
   * The value returned may be {@code null}.
   */
  public String getEndCursor() {
    return endCursor;
  }

  /**
   * A cursor that points to the position after the last result in the batch. May be absent.
   * The value set may be {@code null}.
   */
  public QueryResultBatch setEndCursor(String endCursor) {
    this.endCursor = endCursor;
    return this;
  }

  /**
   * The result type for every entity in entityResults. full for full entities, projection for
   * entities with only projected properties, keyOnly for entities with only a key.
   * The value returned may be {@code null}.
   */
  public String getEntityResultType() {
    return entityResultType;
  }

  /**
   * The result type for every entity in entityResults. full for full entities, projection for
   * entities with only projected properties, keyOnly for entities with only a key.
   * The value set may be {@code null}.
   */
  public QueryResultBatch setEntityResultType(String entityResultType) {
    this.entityResultType = entityResultType;
    return this;
  }

  /**
   * The results for this batch.
   * The value returned may be {@code null}.
   */
  public java.util.List<EntityResult> getEntityResults() {
    return entityResults;
  }

  /**
   * The results for this batch.
   * The value set may be {@code null}.
   */
  public QueryResultBatch setEntityResults(java.util.List<EntityResult> entityResults) {
    this.entityResults = entityResults;
    return this;
  }

  /**
   * The state of the query after the current batch. One of notFinished, moreResultsAfterLimit,
   * noMoreResults.
   * The value returned may be {@code null}.
   */
  public String getMoreResults() {
    return moreResults;
  }

  /**
   * The state of the query after the current batch. One of notFinished, moreResultsAfterLimit,
   * noMoreResults.
   * The value set may be {@code null}.
   */
  public QueryResultBatch setMoreResults(String moreResults) {
    this.moreResults = moreResults;
    return this;
  }

  /**
   * The number of results skipped because of Query.offset.
   * The value returned may be {@code null}.
   */
  public Integer getSkippedResults() {
    return skippedResults;
  }

  /**
   * The number of results skipped because of Query.offset.
   * The value set may be {@code null}.
   */
  public QueryResultBatch setSkippedResults(Integer skippedResults) {
    this.skippedResults = skippedResults;
    return this;
  }

}
