/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * A message that can hold any of the supported value types and associated metadata.
 *
 * At most one of the Value fields may be set. If none are set the value is "null".
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Value extends GenericJson {

  /**
   * A blob key value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String blobKeyValue;

  /**
   * A blob value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String blobValue;

  /**
   * A boolean value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean booleanValue;

  /**
   * A timestamp value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime dateTimeValue;

  /**
   * A double value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double doubleValue;

  /**
   * An entity value. May have no key. May have a key with an incomplete key path. May have a
   * reserved/read-only key.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Entity entityValue;

  /**
   * If the value should be indexed.
   *
   * The indexed property may be set to null. When indexed is true, stringValue is limited to 500
   * characters and the blob value is limited to 500 bytes. Input values by default have indexed set
   * to true; however, you can explicitly set indexed to true if you want. (An output value never
   * has indexed explicitly set to true.) If a value is itself an entity, it cannot have indexed set
   * to true.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean indexed;

  /**
   * An integer value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long integerValue;

  /**
   * A key value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Key keyValue;

  /**
   * The meaning field is reserved and should not be used.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer meaning;

  /**
   * A UTF-8 encoded string value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String stringValue;

  /**
   * A blob key value.
   * The value returned may be {@code null}.
   */
  public String getBlobKeyValue() {
    return blobKeyValue;
  }

  /**
   * A blob key value.
   * The value set may be {@code null}.
   */
  public Value setBlobKeyValue(String blobKeyValue) {
    this.blobKeyValue = blobKeyValue;
    return this;
  }

  /**
   * A blob value.
   * The value returned may be {@code null}.
   */
  public String getBlobValue() {
    return blobValue;
  }

  /**
   * A blob value.
   * The value set may be {@code null}.
   */
  public Value setBlobValue(String blobValue) {
    this.blobValue = blobValue;
    return this;
  }

  /**
   * A boolean value.
   * The value returned may be {@code null}.
   */
  public Boolean getBooleanValue() {
    return booleanValue;
  }

  /**
   * A boolean value.
   * The value set may be {@code null}.
   */
  public Value setBooleanValue(Boolean booleanValue) {
    this.booleanValue = booleanValue;
    return this;
  }

  /**
   * A timestamp value.
   * The value returned may be {@code null}.
   */
  public DateTime getDateTimeValue() {
    return dateTimeValue;
  }

  /**
   * A timestamp value.
   * The value set may be {@code null}.
   */
  public Value setDateTimeValue(DateTime dateTimeValue) {
    this.dateTimeValue = dateTimeValue;
    return this;
  }

  /**
   * A double value.
   * The value returned may be {@code null}.
   */
  public Double getDoubleValue() {
    return doubleValue;
  }

  /**
   * A double value.
   * The value set may be {@code null}.
   */
  public Value setDoubleValue(Double doubleValue) {
    this.doubleValue = doubleValue;
    return this;
  }

  /**
   * An entity value. May have no key. May have a key with an incomplete key path. May have a
   * reserved/read-only key.
   * The value returned may be {@code null}.
   */
  public Entity getEntityValue() {
    return entityValue;
  }

  /**
   * An entity value. May have no key. May have a key with an incomplete key path. May have a
   * reserved/read-only key.
   * The value set may be {@code null}.
   */
  public Value setEntityValue(Entity entityValue) {
    this.entityValue = entityValue;
    return this;
  }

  /**
   * If the value should be indexed.
   *
   * The indexed property may be set to null. When indexed is true, stringValue is limited to 500
   * characters and the blob value is limited to 500 bytes. Input values by default have indexed set
   * to true; however, you can explicitly set indexed to true if you want. (An output value never
   * has indexed explicitly set to true.) If a value is itself an entity, it cannot have indexed set
   * to true.
   * The value returned may be {@code null}.
   */
  public Boolean getIndexed() {
    return indexed;
  }

  /**
   * If the value should be indexed.
   *
   * The indexed property may be set to null. When indexed is true, stringValue is limited to 500
   * characters and the blob value is limited to 500 bytes. Input values by default have indexed set
   * to true; however, you can explicitly set indexed to true if you want. (An output value never
   * has indexed explicitly set to true.) If a value is itself an entity, it cannot have indexed set
   * to true.
   * The value set may be {@code null}.
   */
  public Value setIndexed(Boolean indexed) {
    this.indexed = indexed;
    return this;
  }

  /**
   * An integer value.
   * The value returned may be {@code null}.
   */
  public Long getIntegerValue() {
    return integerValue;
  }

  /**
   * An integer value.
   * The value set may be {@code null}.
   */
  public Value setIntegerValue(Long integerValue) {
    this.integerValue = integerValue;
    return this;
  }

  /**
   * A key value.
   * The value returned may be {@code null}.
   */
  public Key getKeyValue() {
    return keyValue;
  }

  /**
   * A key value.
   * The value set may be {@code null}.
   */
  public Value setKeyValue(Key keyValue) {
    this.keyValue = keyValue;
    return this;
  }

  /**
   * The meaning field is reserved and should not be used.
   * The value returned may be {@code null}.
   */
  public Integer getMeaning() {
    return meaning;
  }

  /**
   * The meaning field is reserved and should not be used.
   * The value set may be {@code null}.
   */
  public Value setMeaning(Integer meaning) {
    this.meaning = meaning;
    return this;
  }

  /**
   * A UTF-8 encoded string value.
   * The value returned may be {@code null}.
   */
  public String getStringValue() {
    return stringValue;
  }

  /**
   * A UTF-8 encoded string value.
   * The value set may be {@code null}.
   */
  public Value setStringValue(String stringValue) {
    this.stringValue = stringValue;
    return this;
  }

}
